==> hoteldruid-mod-bg_2.2.0-1.zip: bg/gestione_utenti.php <==
<?php

switch ($messaggio) {

case "Il <b>nome</b> dell'utente":  		$messaggio = "<b>Името</b> на потребител"; break;
case "verrà cambiato da":  			$messaggio = "ще бъде променено от"; break;
case "a":  					$messaggio = "на"; break;
case "Il <b>login</b> dell'utente":  		$messaggio = "<b>Логинът</b> на потребите"; break;
case "password conservata in chiaro":  		$messaggio = "паролата е запазена в обикновен текст"; break;
case "password conservata criptata con md5":  	$messaggio = "запазената порола е криптирана с md5"; break;
case "password conservata criptata con mcrypt":	$messaggio = "запазената парола е криптирана с mcrypt"; break;
case "password conservata criptata con mhash":	$messaggio = "запазената парола е криптирана с mhash"; break;
case "disabilitato":  				$messaggio = "деактивирано"; break;
case "Inserisci una nuova password":  		$messaggio = "Въведете нова парола"; break;
case "Ripeti la password":  			$messaggio = "Повторете паролата"; break;
case "Continua":  				$messaggio = "Продължете"; break;
case "Torna indietro":  			$messaggio = "Обратно"; break;
case "<div style=\"display: inline; color: red;\">Esiste già</div> un utente chiamato":	$messaggio = "<div style=\"display: inline; color: red;\">Вече съществува</div> потребител  с име"; break;
case "Nuova password dell'utente":  		$messaggio = "Нова парола за потребител"; break;
case "<div style=\"display: inline; color: red;\">non</div> inserita correttamente":	$messaggio = "<div style=\"display: inline; color: red;\">не е </div>въведена правилно"; break;
case "<b>Non</b> è stato effettuato nessun cambiamento":	$messaggio = "<b>Никакви промени</b> не са направени"; break;
case "Esiste già un utente chiamato":  		$messaggio = "Вече съществува потребител с име"; break;
case "Le nuove password non coincidono":  	$messaggio = "Новите пароли не съвпадат"; break;
case "Inserisci una nuova password per l'utente":	$messaggio = "Въведете нова парола за потребител"; break;
case "Nuova password":  			$messaggio = "Нова парола"; break;
case "N°":  					$messaggio = "N°"; break;
case "nome":  					$messaggio = "име"; break;
case "login":  					$messaggio = "логин"; break;
case "modifica":  				$messaggio = "променете"; break;
case "password criptata con md5":  		$messaggio = "паролата е криприрана с md5"; break;
case "password criptata con mcrypt":  		$messaggio = "паролата е криприрана с mcrypt"; break;
case "password criptata con mhash":  		$messaggio = "паролата е криприрана с mhash"; break;
case "password":  				$messaggio = "парола"; break;
case "privilegi":  				$messaggio = "права"; break;
case "Amministratore":  			$messaggio = "администратор"; break;
case "Abilitare per usare altri utenti":  	$messaggio = "Активирайте за да използвате други потребители"; break;
case "Modifica gli utenti":  			$messaggio = "Редактирайте потребители"; break;
case "Aggiungi":  				$messaggio = "Добавете"; break;
case "un nuovo utente chiamato":  		$messaggio = "нов потребител наречен"; break;
case "dell'utente":  				$messaggio = "of user"; break;
case "del gruppo":  				$messaggio = "of group"; break;
case "dall'utente":  				$messaggio = "от потребител"; break;
case "Privilegi importati":  			$messaggio = "Правата са импортирани"; break;
case "Importa":  				$messaggio = "Импортирайте"; break;
case "SI":  					$messaggio = "YES"; break;
case "NO":  					$messaggio = "NO"; break;
case "Gestione degli utenti di hoteldruid":	$messaggio = "HotelDruid users management"; break;
case "gruppi":  				$messaggio = "groups"; break;
case "Aggiornati i gruppi dell'utente":  	$messaggio = "Updated groups of user"; break;
case "Gruppi dell'utente":  			$messaggio = "Groups of user"; break;
case "Nuovo gruppo":  				$messaggio = "New group"; break;
case "Esiste già un gruppo chiamato":  		$messaggio = "Already exists a group called"; break;
case "Modifica":  				$messaggio = "Modify"; break;
case "cancella":  				$messaggio = "delete"; break;
case "Si è sicuri di voler <b style=\"font-weight: normal; color: red;\">cancellare</b> l'utente":	$messaggio = "Are you sure you want to <b style=\"font-weight: normal; color: red;\">delete</b> user"; break;
case "privilegi e personalizzazioni":  		$messaggio = "privileges and customizations"; break;
case "solo i privilegi":  			$messaggio = "only privileges"; break;
case "solo le personalizzazioni":  		$messaggio = "only customizations"; break;
case "Personalizzazioni importate":  		$messaggio = "Customizations imported"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-bg_3.0.8-1.zip: bg/gestione_utenti.php <==
<?php

switch ($messaggio) {

case "Il <b>nome</b> dell'utente":  		$messaggio = "<b>Името</b> на потребител"; break;
case "verrà cambiato da":  			$messaggio = "ще бъде променено от"; break;
case "a":  					$messaggio = "на"; break;
case "Il <b>login</b> dell'utente":  		$messaggio = "<b>Логинът</b> на потребите"; break;
case "password conservata in chiaro":  		$messaggio = "паролата е запазена в обикновен текст"; break;
case "password conservata criptata con md5":  	$messaggio = "запазената порола е криптирана с md5"; break;
case "password conservata criptata con mcrypt":	$messaggio = "запазената парола е криптирана с mcrypt"; break;
case "password conservata criptata con mhash":	$messaggio = "запазената парола е криптирана с mhash"; break;
case "disabilitato":  				$messaggio = "деактивирано"; break;
case "Inserisci una nuova password":  		$messaggio = "Въведете нова парола"; break;
case "Ripeti la password":  			$messaggio = "Повторете паролата"; break;
case "Continua":  				$messaggio = "Продължете"; break;
case "Torna indietro":  			$messaggio = "Обратно"; break;
case "<div style=\"display: inline; color: red;\">Esiste già</div> un utente chiamato":	$messaggio = "<div style=\"display: inline; color: red;\">Вече съществува</div> потребител  с име"; break;
case "Nuova password dell'utente":  		$messaggio = "Нова парола за потребител"; break;
case "<div style=\"display: inline; color: red;\">non</div> inserita correttamente":	$messaggio = "<div style=\"display: inline; color: red;\">не е </div>въведена правилно"; break;
case "<b>Non</b> è stato effettuato nessun cambiamento":	$messaggio = "<b>Никакви промени</b> не са направени"; break;
case "Esiste già un utente chiamato":  		$messaggio = "Вече съществува потребител с име"; break;
case "Le nuove password non coincidono":  	$messaggio = "Новите пароли не съвпадат"; break;
case "Inserisci una nuova password per l'utente":	$messaggio = "Въведете нова парола за потребител"; break;
case "Nuova password":  			$messaggio = "Нова парола"; break;
case "N°":  					$messaggio = "N°"; break;
case "nome":  					$messaggio = "име"; break;
case "login":  					$messaggio = "логин"; break;
case "modifica":  				$messaggio = "променете"; break;
case "password criptata con md5":  		$messaggio = "паролата е криприрана с md5"; break;
case "password criptata con mcrypt":  		$messaggio = "паролата е криприрана с mcrypt"; break;
case "password criptata con mhash":  		$messaggio = "паролата е криприрана с mhash"; break;
case "password":  				$messaggio = "парола"; break;
case "privilegi":  				$messaggio = "права"; break;
case "Amministratore":  			$messaggio = "администратор"; break;
case "Abilitare per usare altri utenti":  	$messaggio = "Активирайте за да използвате други потребители"; break;
case "Modifica gli utenti":  			$messaggio = "Редактирайте потребители"; break;
case "Aggiungi":  				$messaggio = "Добавете"; break;
case "un nuovo utente chiamato":  		$messaggio = "нов потребител наречен"; break;
case "dell'utente":  				$messaggio = "of user"; break;
case "del gruppo":  				$messaggio = "of group"; break;
case "dall'utente":  				$messaggio = "от потребител"; break;
case "Privilegi importati":  			$messaggio = "Правата са импортирани"; break;
case "Importa":  				$messaggio = "Импортирайте"; break;
case "SI":  					$messaggio = "YES"; break;
case "NO":  					$messaggio = "NO"; break;
case "Gestione Utenti":  			$messaggio = "Users Management"; break;
case "Gestione degli utenti di hoteldruid":	$messaggio = "HotelDruid users management"; break;
case "Gestione degli utenti":			$messaggio = "Users management"; break;
case "gruppi":  				$messaggio = "groups"; break;
case "Aggiornati i gruppi dell'utente":  	$messaggio = "Updated groups of user"; break;
case "Gruppi dell'utente":  			$messaggio = "Groups of user"; break;
case "Nuovo gruppo":  				$messaggio = "New group"; break;
case "Esiste già un gruppo chiamato":  		$messaggio = "Already exists a group called"; break;
case "Modifica":  				$messaggio = "Modify"; break;
case "cancella":  				$messaggio = "delete"; break;
case "Si è sicuri di voler <b style=\"font-weight: normal; color: red;\">cancellare</b> l'utente":	$messaggio = "Are you sure you want to <b style=\"font-weight: normal; color: red;\">delete</b> user"; break;
case "privilegi e personalizzazioni":  		$messaggio = "privileges and customizations"; break;
case "solo i privilegi":  			$messaggio = "only privileges"; break;
case "solo le personalizzazioni":  		$messaggio = "only customizations"; break;
case "Personalizzazioni importate":  		$messaggio = "Customizations imported"; break;
case "privilegi, personalizzazioni e gruppi":	$messaggio = "privileges, customizations and groups"; break;
case "privilegi e gruppi":  			$messaggio = "privileges and groups"; break;
case "personalizzazioni e gruppi":  		$messaggio = "customizations and groups"; break;
case "solo i gruppi":  				$messaggio = "only groups"; break;
case "Gruppi importati":  			$messaggio = "Groups imported"; break;
case "Password aggiornata":  			$messaggio = "Password updated"; break;
case "Password troppo debole":			$messaggio = "Password too weak"; break;
case "almeno":  				$messaggio = "at least"; break;
case "caratteri":  				$messaggio = "characters"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
